@@ -79,7 +79,7 @@ class Learner():
         try:
             for self.iter,(x,y) in enumerate(dl):
                 if len(x) > 2: self.one_batch(x, y)
-                else: print('Batch smaller that 3, skiping')
+                # else: print('Skiping batch smaller that 2')
                 if self.train: self.epf += 1./self.iters
         except CancelEpochException: self('after_cancel_epoch')
 
